function gadget:GetInfo()
	return 
	{
		name = "Main Rules",
		desc = "Main Rules Module for Squad Troopers.",
		author = "Argh",
		date = "December 28th, 2008",
		license = "(C) Wolfe Games",
		layer = 1,
		enabled = true
	}
end

local Health, maxHealth, paralyzeDamage = 0,0,0
local SetUnitHealth = Spring.SetUnitHealth
local GetUnitHealth = Spring.GetUnitHealth

local exceptionList = {}
local KitList = {}
local DaughterList = {}
local BoxList = {}
local BoomBoxList = {}
local Scores = {score}
local RespawnTable = {}
local RespawnLocation = {}
local HitScore = 0

local alwaysTakesDamage = {}
local Assault_Rifle, MachineGun, Rocket_Launcher, SMG, Frag_Gren, Flash_Gren, Sniper_Rifle
local Random, Random2 = 0,0
local math_rand = math.random

local CMD_BUY_MEDIPACK = 32700
local CMD_USE_MEDIPACK = 32701
local CMD_BUY_ARMOR = 32702
local CMD_BUY_SCANNER = 32703
local CMD_BUY_MINE = 32704
local CMD_USE_MINE = 32705

if (gadgetHandler:IsSyncedCode()) then

BuyMediPack = {	
		id=CMD_BUY_MEDIPACK,
		type=CMDTYPE.ICON,
		name="Buy MediPack",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/BUY_MEDIPACK.png",
		tooltip="MediPack:  allows a Trooper to heal himself.\r\nTroopers can only have one at a time.  Costs $25",
		action="buy medipack",
		cursor='Guard'
		}

UseMediPack = {
		id=CMD_USE_MEDIPACK,
		type=CMDTYPE.ICON,
		name="Use Medipack",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/USE_MEDIPACK.png",
		tooltip="Medipack: allows a Trooper to heal himself.  Only good for one use.",
		action="use medipack",
		cursor='Guard'
		}

BuyArmor = {	
		id=CMD_BUY_ARMOR,
		type=CMDTYPE.ICON,
		name="Buy Armor",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/BUY_ARMOR.png",
		tooltip="Armor: gives Trooper better armor protection.  Costs $50.",
		action="buy armor",
		cursor='Guard'
		}


BuyScanner = {	
		id=CMD_BUY_SCANNER,
		type=CMDTYPE.ICON,
		name="Buy Scanner",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/BUY_SCANNER.png",
		tooltip="Scanner: gives Trooper the ability to see enemies through walls.\r\nHidden troops show up as red blotches if they move.  Costs $100.",
		action="buy scanner",
		cursor='Guard'
		}

BuyMine = {	
		id=CMD_BUY_MINE,
		type=CMDTYPE.ICON,
		name="Buy Mine",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/BUY_MINE.png",
		tooltip="Mine: Hidden explosive, can be dropped on ground.\r\n  Fairly powerful, cannot be seen by enemies.  Costs $200.",
		action="buy mine",
		cursor='Guard'
		}

UseMine = {	
		id=CMD_USE_MINE,
		type=CMDTYPE.ICON,
		name="Use Mine",
		onlyTexture=true,	
		texture="&.9x.9&bitmaps/icons/blank.tif&bitmaps/icons/USE_MINE.png",
		tooltip="Drops a landmine on the ground.  Triggers if enemies get close\r\nBe careful!  The explosion can hurt your troops.",
		action="buy mine",
		cursor='Guard'
		}


function gadget:Initialize()
	-- Set up weapon classes, for special damage
	for i=1,#WeaponDefs do  --search all WeaponDef entries
		if string.find(WeaponDefs[i].description,"(teamdamage)") then
			table.insert(exceptionList,i,1)
		end
		if string.find(WeaponDefs[i].description,"Assault Rifle") then
			Assault_Rifle = i
		end
		if string.find(WeaponDefs[i].description,"Machine Gun") then
			MachineGun = i
		end
		if string.find(WeaponDefs[i].description,"Rocket Launcher") then
			Rocket_Launcher = i
		end
		if string.find(WeaponDefs[i].description,"SMG") then
			SMG = i
		end
		if string.find(WeaponDefs[i].description,"Fragmentation Grenade") then
			Frag_Gren = i
		end
		if string.find(WeaponDefs[i].description,"Flashbang Grenade") then
			Flash_Gren = i
		end
		if string.find(WeaponDefs[i].description,"Sniper Rifle") then
			Sniper_Rifle = i
		end
	end

	-- Set special status for weapons that cause team damage
	for ud,_ in pairs(UnitDefs) do  -- search all UnitDef entries
		if UnitDefs[ud].customParams.always_takes_damage == 'yes' then
			table.insert(alwaysTakesDamage,ud,1)
		end
		if UnitDefs[ud].customParams.unit_ui_category == 'infantry' then
			table.insert(KitList,ud,1)
		end
		if UnitDefs[ud].customParams.special == 'yakuza_daughter' then
			table.insert(DaughterList,ud,1)
		end
		if UnitDefs[ud].customParams.special == 'deathbox' then
			table.insert(BoxList,ud,1)
		end
		if UnitDefs[ud].customParams.special == 'explosivebox' then
			table.insert(BoomBoxList,ud,1)
		end
	end
end

function gadget:UnitCreated(u, ud, team)
	-- Put all of the special objects that can be bought into the list, make them available.
	if KitList[Spring.GetUnitDefID(u)] then
		Spring.InsertUnitCmdDesc(u, BuyMediPack)
		Spring.InsertUnitCmdDesc(u, BuyArmor)
		Spring.InsertUnitCmdDesc(u, BuyScanner)
		Spring.InsertUnitCmdDesc(u, BuyMine)
	end
	if DaughterList[ud] then
		Spring.SetUnitNeutral(u,true)
	end
	if BoxList[ud] then
		Spring.SetUnitNeutral(u,true)
	end
end

function gadget:AllowCommand(u,ud,team,cmd,param,opts)
	if cmd  == CMD.SELFD then
		return false
	end
	return true
end

function gadget:CommandFallback(u, ud, team, cmd, param, opts)
	if cmd  == CMD_BUY_MEDIPACK then
		local money = Spring.GetTeamResources(team, 'metal')
		local cmdID = Spring.FindUnitCmdDesc(u, CMD_USE_MEDIPACK)
		if cmdID == nil then
			if money >= 25 then
				Spring.InsertUnitCmdDesc(u, UseMediPack)
				Spring.UseTeamResource(team,'m',25)
			
			else
				Spring.Echo("Not enough money!")
			end
		else
			Spring.Echo("Troopers can only carry one MediPack at a time.")
		end
		return true, true;
	end
	if cmd  == CMD_USE_MEDIPACK then
		local health, maxhealth = Spring.GetUnitHealth(u)
		if health + 75 < maxhealth then
			SetUnitHealth(u,{health = health + 75})
		else
			SetUnitHealth(u,{health = maxhealth})
		end
		local cmdID = Spring.FindUnitCmdDesc(u, CMD_USE_MEDIPACK)
		if cmdID ~= nil then
			Spring.RemoveUnitCmdDesc(u, cmdID)
		end		
		return true, true;
	end
	if cmd  == CMD_BUY_ARMOR then
		local health, maxhealth = Spring.GetUnitHealth(u)
		local money = Spring.GetTeamResources(team, 'metal')
		if money >= 50 then
			Spring.SetUnitMaxHealth(u,maxhealth + 150)
			SetUnitHealth(u,{health = health + 150})
			Spring.UseTeamResource(team,'m',50)
			local cmdID = Spring.FindUnitCmdDesc(u, CMD_BUY_ARMOR)
			if cmdID ~= nil then
				Spring.RemoveUnitCmdDesc(u, cmdID)
			end	
		else
			Spring.Echo("Not enough money!")
		end
		return true, true;
	end
	if cmd  == CMD_BUY_SCANNER then
		local money = Spring.GetTeamResources(team, 'metal')
		if money >= 100 then
			Spring.SetUnitSensorRadius(u,'seismic',800)
			Spring.UseTeamResource(team,'m',100)
			local cmdID = Spring.FindUnitCmdDesc(u, CMD_BUY_SCANNER)
			if cmdID ~= nil then
				Spring.RemoveUnitCmdDesc(u, cmdID)
			end	
		else
			Spring.Echo("Not enough money!")
		end
		return true, true;
	end
	if cmd  == CMD_BUY_MINE then
		local money = Spring.GetTeamResources(team, 'metal')
		local cmdID = Spring.FindUnitCmdDesc(u, CMD_USE_MINE)
		if cmdID == nil then
			if money >= 200 then
				Spring.InsertUnitCmdDesc(u, UseMine)
				Spring.UseTeamResource(team,'m',200)
			else
				Spring.Echo("Not enough money!")
			end
		else
			Spring.Echo("Troopers can only carry one Mine at a time.")
		end
		return true, true;
	end
	if cmd  == CMD_USE_MINE then
		local x,y,z = Spring.GetUnitPosition(u)
		Spring.CreateUnit("landmine",x,y,z, 0, team)		
		local cmdID = Spring.FindUnitCmdDesc(u, CMD_USE_MINE)
		if cmdID ~= nil then
			Spring.RemoveUnitCmdDesc(u, cmdID)
		end		
		return true, true;
	end
	return false
end


local function StartGameState()
	local Teams = Spring.GetTeamList() -- Get total number of Teams
	-- Set up score table
	TeamNum = #Teams
	for i = 0,TeamNum,1 do
		table.insert(Scores,i,0)
	end
	--  Randomly pick a Team to have the Objective
	local SpawnTeams = TeamNum - 1
	for i = 0,SpawnTeams,1 do
		Spring.SetTeamResource(i,'ms',10000)
		local UnitSpawns = Spring.GetTeamUnits(i)
		if UnitSpawns[1] ~= nil then
			--Spring.Echo("found a team")
			local x,y,z = Spring.GetUnitPosition(UnitSpawns[1])
			--Spring.Echo(i,x,y,z)
			table.insert(RespawnLocation,{i,x,y,z})
		end
	end

	TeamNum = TeamNum - 2  -- Lose the Gaia Team, offset by 1	
	local RandomTeamChoice = math_rand(0,TeamNum)

	--Choose Objective
	local RandomObjective = math_rand(1,3)
	--Spring.Echo("Team "..RandomTeamChoice.." has been assigned Objective "..RandomObjective)
	SendToUnsynced("ObjectiveState", RandomTeamChoice, RandomObjective)

	if RandomObjective == 1 then  -- Guard the box!
		local UnitSpawns = Spring.GetTeamUnits(RandomTeamChoice)
		Spring.AddTeamResource(RandomTeamChoice,'m',100)
		local x,y,z = Spring.GetUnitPosition(UnitSpawns[1])
		Spring.CreateUnit("death_box", x - 48,y,z - 48, 0, RandomTeamChoice)
	end

	if RandomObjective == 2 then  -- Guard the Yakuza's Daughter!
		local UnitSpawns = Spring.GetTeamUnits(RandomTeamChoice)
		Spring.AddTeamResource(RandomTeamChoice,'m',50)
		local x,y,z = Spring.GetUnitPosition(UnitSpawns[1])
		Spring.CreateUnit("yakuza_daughter", x - 48,y,z - 48, 0, RandomTeamChoice)
	end

	if RandomObjective == 3 then -- Box o' Dynamite!
		local UnitSpawns = Spring.GetTeamUnits(RandomTeamChoice)
		Spring.AddTeamResource(RandomTeamChoice,'m',150)
		local x,y,z = Spring.GetUnitPosition(UnitSpawns[1])
		Spring.CreateUnit("explosive_box", x - 48,y,z - 48, 0, RandomTeamChoice)
	end
end


function gadget:UnitDestroyed(unitID, unitDefID, teamID)
	local Repeated = 0
	--Spring.Echo("Dead returned to Respawn")
	if KitList[unitDefID] then
		if RespawnTable[1] ~= nil then
			for i,k in ipairs(RespawnTable) do
				if k[1] == teamID and k[2] == unitDefID and k[3] == unitID then
					--Spring.Echo("Repeat Found")
					Repeated = 1
				end
			end
			if Repeated == 0 then
				table.insert(RespawnTable,{teamID,unitDefID,unitID})
			end
		else
			table.insert(RespawnTable,{teamID,unitDefID,unitID})
		end
	end

	if BoxList[unitDefID] or DaughterList[unitDefID] or BoomBoxList[unitDefID] then
		Spring.SendCommands({"endgraph 0"})
		local lastK = 0
		local winner = 0
		for i,k in ipairs (Scores) do
		--Spring.Echo("Team "..(i - 1).." score is "..k)
			if k > lastK then 
				lastK = k
				winner = i - 1
			end
		end
		SendToUnsynced("GameEnded",winner,lastK)

		local KillThemAll = Spring.GetAllUnits()
		for i,k in ipairs(KillThemAll) do
			Spring.DestroyUnit(k,false,true)
		end
	end
	
end

function gadget:UnitTaken(unitID, unitDefID, unitTeam, newTeam)
	--Spring.Echo("Capture occurred")
	local ScoreObject = 0
	if DaughterList[unitDefID] then
		ScoreObject = Scores[newTeam + 1] + 5000
		Scores[newTeam + 1] = ScoreObject

		Spring.SendCommands({"endgraph 0"})
		local lastK = 0
		local winner = 0
		for i,k in ipairs (Scores) do
		--Spring.Echo("Team "..(i - 1).." score is "..k)
			if k > lastK then 
				lastK = k
				winner = i - 1
			end
		end
		SendToUnsynced("GameEnded",winner,lastK)
		local KillThemAll = Spring.GetAllUnits()

		for i,k in ipairs(KillThemAll) do
			Spring.DestroyUnit(k,false,true)
		end
	end
	if BoxList[unitDefID] then
		ScoreObject = Scores[newTeam + 1] + 2000
		Scores[newTeam + 1] = ScoreObject

		Spring.SendCommands({"endgraph 0"})
		local lastK = 0
		local winner = 0
		for i,k in ipairs (Scores) do
		--Spring.Echo("Team "..(i - 1).." score is "..k)
			if k > lastK then 
				lastK = k
				winner = i - 1
			end
		end
		SendToUnsynced("GameEnded",winner,lastK)
		local KillThemAll = Spring.GetAllUnits()

		for i,k in ipairs(KillThemAll) do
			Spring.DestroyUnit(k,false,true)
		end
	end
end

function gadget:GameFrame(f)
	if f % 33 < 0.1 then
		for i,k in ipairs (Scores) do
			--Spring.Echo("Team "..(i - 1).." score is "..k)
			SendToUnsynced("ScoreChanged",(i-1),_,f,math.floor(k))
		end	
	end

	if f == 16 then
		Spring.SendCommands({"endgraph 0"})
		StartGameState()
	end

	if f % 160 < 0.1 then
		if RespawnTable[1] ~= nil then
			for i,k in ipairs (RespawnTable) do
				--Spring.Echo(k[2])
				for j,l in ipairs(RespawnLocation) do
					--Spring.Echo(l[1])
					if k[1] == l[1] then  -- team ids match!  Great!
						--Spring.Echo("Checking")
						local mynumber = k[2]
						local names = UnitDefs[mynumber].name
						--Spring.Echo(names,l[2],l[3],l[4])
						local RandomX = math_rand(-48,48)
						local RandomZ = math_rand(-48,48)
						Spring.CreateUnit(names, l[2]+RandomX,l[3],l[4]+RandomZ,0, k[1])
						table.remove(RespawnTable,i)						
					end
				end
			end
		end
	end
end

function gadget:UnitDamaged(unitID, unitDefID, unitTeam, damage, paralyzer, weaponID, attackerID, attackerDefID, attackerTeam)
	Random, Random2 = 0,0
	--No Team Damage, except from flash, frag and rockets, etc.
	Health, maxHealth, paralyzeDamage = GetUnitHealth(unitID)
	if unitTeam == attackerTeam then		
		if not exceptionList[weaponID] and not alwaysTakesDamage[unitDefID] then
			if paralyzer then
				SetUnitHealth(unitID,{paralyze = damage + paralyzeDamage})
			else
				if Health + damage < maxHealth then
					SetUnitHealth(unitID,{health = Health + damage})
				else
					SetUnitHealth(unitID,{health = maxHealth})
				end
			end
		end
	else  -- Now we have the uber-nifty special-damage stuff.
		if attackerID ~= nil and attackerTeam ~= nil then

		if weaponID == Assault_Rifle then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(10,20))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--Boom!  Headshot, baby.  Damage increased from 3-5
				Random2 = (damage * math_rand(25,35))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
		end
		if weaponID == MachineGun then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(35,40))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--Boom!  Headshot, baby.  Damage increased from 4-6
				Random2 = (damage * math_rand(45,60))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
		end
		if weaponID == Rocket_Launcher then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(20,30))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--No headshots for Rocket Launchers, do nothing here.
			end
		end
		if weaponID == SMG then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(1,5))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--Boom!  Headshot, baby.  Damage increased from 1-3
				Random2 = (damage * math_rand(15,30))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
		end
		if weaponID == Sniper_Rifle then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(10,20))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--Boom!  Headshot, baby.  Damage increased from 3-5
				Random2 = (damage * math_rand(45,65))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
		end
		if weaponID == Frag_Gren then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--normal damage results, number subtracted is in addition to damage from weapon.
				Random2 = (damage * math_rand(20,40))/10
				SetUnitHealth(unitID,{health = Health - Random2})
				HitScore = Scores[attackerTeam + 1] + damage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--armor nullified results, we're going to add some health back on
				Random2 = (damage * math_rand(1,8))/10
				SetUnitHealth(unitID,{health = Health + Random2})
				HitScore = Scores[attackerTeam + 1] + damage - Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random == 6 then
				--No headshots for Frag Grenades, do nothing here.
			end
		end
		if weaponID == Flash_Gren then
			Random = math_rand(1,6)
			if Random > 0 and Random < 4 then
				--Extra stun!  Ouch!
				Random2 = (damage * math_rand(40,60))/10
				SetUnitHealth(unitID,{paralyze = paralyzeDamage + Random2})
				HitScore = Scores[attackerTeam + 1] + paralyzeDamage + Random2
				Scores[attackerTeam + 1] = HitScore
			end
			if Random > 3 and Random < 6 then
				--Got lucky, no additional stun.
			end
			if Random == 6 then
				--No headshots for Flash Grenades, do nothing here.
			end
		end
		Spring.AddTeamResource(attackerTeam,'m',damage + Random2 / 3)
	end

	end
	-- Diagnostic code, for reviewing scoring structure in realtime.
	--[[for i,k in ipairs (Scores) do
		Spring.Echo("Team "..(i - 1).." score is "..k)
	end]]
end

function gadget:GameOver()
	Spring.SendCommands({"endgraph 0"})
	local lastK = 0
	local winner = 0
	for i,k in ipairs (Scores) do
	--Spring.Echo("Team "..(i - 1).." score is "..k)
		if k > lastK then 
			lastK = k
			winner = i - 1
		end
	end
	SendToUnsynced("GameEnded",winner,lastK)
end

else

local gameOver, Winner, TopScore, objectiveScreen = 0,0,0,0
local x,y = gl.GetViewSizes()
local textSize = 64 * (x / 1600)
local FinalScoreX = x * 0.5
local FinalScoreY = y * 0.5
local FinalPlacementY = y * 0.45
local FinalPlacementY2 = y * 0.4
local FinalPlacementY3 = y * 0.35
local FinalPlacementY4 = y * 0.3

local Desc1 = y * 0.7
local Desc2 = y * 0.66
local Desc3= y * 0.62
local Desc4 = y * 0.58
local Desc5 = y * 0.54
local Desc6 = y * 0.50
local Desc7 = y * 0.46
local Desc8 = y * 0.42
local Desc9 = y * 0.38
local Desc10 = y * 0.30
local Desc11 = y * 0.24
local IsGUIHidden  = Spring.IsGUIHidden
local glColor = gl.Color
local glText = gl.Text
local glTexRect = gl.TexRect
local glTexture = gl.Texture
local winnerString
local ObjectiveString, NotObjectiveString
local team, frame = 0,0
local EndBack = 'bitmaps/ui/endback.png'
function gadget:RecvFromSynced(name,a,b)
	if (name == 'GameEnded') then
		--Spring.Echo("received event")
		gameOver = 1
		Winner = a
		TopScore = b
		winnerString = tostring("Team "..Winner.." wins the match, with "..math.floor(TopScore).." points!")
	end

	if(name == 'ObjectiveState') then 
		objectiveScreen = 1
		ObjectiveTeam = a
		Objective = b
		if Objective == 1 then
			ObjectiveString = "You have been given a case full of... a dangerous item.  Keep it safe.  Get some extra guns, you'll need 'em."
			NotObjectiveString = "One a' these merc squads has something we want.  It's a little box, see.  Get it for us."
		end
		if Objective == 2 then
			ObjectiveString = "The local Yakuza boss has hired you as protection for his daughter.  We've given you a little money-  keep her safe and sound."
			NotObjectiveString = "Little lady around here... she's the local Yak lord's kid.  Big prizes for whoever nabs her."
		end
		if Objective == 3 then
			ObjectiveString = "We've given you a ... box.  The contents are... volatile.  Guard it well."
			NotObjectiveString = "Rumor has it that there's a box of dynamite around here.  Make it go boom."
		end
		team = Spring.GetLocalTeamID()
	end
end

function gadget:KeyPress(key, mods, isRepeat)
	if key == 27 then
		if gameOver == 0 then
    			objectiveScreen = 0
		else
			Spring.SendCommands({"quit"})
		end
	end
end


function gadget:DrawScreen()
	if objectiveScreen == 1 then
		frame = Spring.GetGameFrame()
		if frame < 10 * 32 then
			if IsGUIHidden() == false then
				glColor(0.0,0.0,0.0,1.0)
				glTexture(EndBack)
				glTexRect(0,0,x,y)
				glColor(1.0,1.0,1.0,1.0)
				glText("Welcome to Merc Squad.", FinalScoreX, Desc1, textSize, "oc")
				glText("The rules are as follows:", FinalScoreX, Desc2, textSize * 0.5, "oc")
				glText("Hire mercenaries.  Equip your mercenary troops with gear, and attempt to kill the other mercenaries.", FinalScoreX, Desc3, textSize * 0.5, "oc")
				glText("You only get 45 seconds after this message to equip and buy troops, so do it fast!", FinalScoreX, Desc4, textSize * 0.5, "oc")
				glText("One team has a special objective... but you don't know who.", FinalScoreX, Desc5, textSize * 0.5, "oc")
				glText("It may be something you can capture or destroy, for a huge score bonus.", FinalScoreX, Desc6, textSize * 0.5, "oc")
				glText("When someone achieves the Objective (or destroys it) the game ends.", FinalScoreX, Desc7, textSize * 0.5, "oc")	
				glText("Troops respawn after death, every 10 seconds.  Use a variety of troops to achieve the Objective.", FinalScoreX, Desc8, textSize * 0.5, "oc")
				glText("The highest score at the end wins.  Good luck, and good hunting.  Hit your Escape key (ESC) to exit this briefing.", FinalScoreX, Desc9, textSize * 0.5, "oc")
				if team == ObjectiveTeam then
					glColor(1.0,0,0,1.0)
					glText("You have the objective!  Nobody else knows but you.  Tell no one!", FinalScoreX, Desc10, textSize * 0.6, "nc")
					glColor(1.0,1.0,0,1.0)
					glText(ObjectiveString, FinalScoreX, Desc11, textSize * 0.4, "nc")
				else
					glColor(0.0,1.0,0,1.0)
					glText(NotObjectiveString, FinalScoreX, Desc10, textSize * 0.4, "nc")
				end
			end
		else
			objectiveScreen = 0
		end
	end
	if gameOver == 1 then
		--Spring.Echo("game over")
		if IsGUIHidden() == false then
		glColor(0.0,0.0,0.0,1.0)
		glTexture(EndBack)
		glTexRect(0,0,x,y)
		glColor(1.0,1.0,1.0,1.0)
		glText(winnerString, FinalScoreX, FinalScoreY, textSize, "noc")
		glText("This game was made by Wolfe Games.", FinalScoreX, FinalPlacementY, textSize * 0.5, "noc")
		glText("To learn about other games being developed for the Spring engine, please visit:", FinalScoreX, FinalPlacementY2, textSize * 0.5, "noc")
		glColor(0.3,0.7,1.0,1.0)
		glText("www.wolfegames.com", FinalScoreX, FinalPlacementY3, textSize * 0.7, "nc")
		glColor(1.0,1.0,1.0,1.0)
		glText("To exit this game, hit ESC", FinalScoreX, FinalPlacementY4, textSize * 0.7, "noc")
		end
	end
end

end