function widget:GetInfo()
	return {
		name = "Team Display (ALL)",
		desc = "Shows a team color circle or direction indicator for units",
		author = "Argh",
		date = "August 21, 2008",
		license = "(C) Wolfe Games 2008",
		layer = -2,
		enabled = true
		}
end

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

local SoldierList = {}

local ARList = {}
local MGUNList = {}
local RLList = {}
local SMGList = {}
local SNList = {}
local STList = {}

local StaticList = {}

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--
-- Variable Declarations
--
local glResetState = gl.ResetState
local GL_SRC_ALPHA = GL.SRC_ALPHA
local GL_ONE = GL.ONE
local glTexCoord = gl.TexCoord
local glVertex = gl.Vertex
local glCreateList = gl.CreateList
local glBeginEnd = gl.BeginEnd
local GL_QUADS = GL.QUADS
local GetVisibleUnits = Spring.GetVisibleUnits
local GetUnitTeam = Spring.GetUnitTeam
local GetUnitRadius = Spring.GetUnitRadius
local GetUnitBasePosition = Spring.GetUnitBasePosition
local GetUnitHeading = Spring.GetUnitHeading
local GetUnitDefID = Spring.GetUnitDefID
local IsUnitSelected = Spring.IsUnitSelected
local GetTeamColor = Spring.GetTeamColor
local IsUnitVisible = Spring.IsUnitVisible
local GetGroundNormal = Spring.GetGroundNormal
local glLineWidth = gl.LineWidth
local glDepthTest = gl.DepthTest
local glPolygonOffset = gl.PolygonOffset
local glColor = gl.Color
local glTexture = gl.Texture
local GL_LEQUAL = GL.LEQUAL
local glBlending = gl.Blending
local glDepthMask = gl.DepthMask
local glDrawListAtUnit = gl.DrawListAtUnit
local UnitIDList, id, teamID, r, g, b
local radius, direction, directionTwo
local LOS =   "LuaUI/Graphics/LOS.tga"
local OUTER =   "LuaUI/Graphics/OUTER.tga"
local INNER =   "LuaUI/Graphics/INNER.tga"
local textureFour =   "LuaUI/Graphics/StaticBlob.tga"
local turnMe = 0
local file

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
function widget:Initialize()

--Spring.SendCommands("luaui disablewidget P.U.R.E. Team Display (SELECTED)")

	for ud,_ in pairs(UnitDefs) do
		if UnitDefs[ud].customParams.team_circle_param == 'soldier' then
			table.insert(SoldierList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'AR' then
			table.insert(ARList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'MGUN' then
			table.insert(MGUNList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'RL' then
			table.insert(RLList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'SMG' then
			table.insert(SMGList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'SN' then
			table.insert(SNList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_type_param == 'ST' then
			table.insert(STList,ud,1)
		end
		if UnitDefs[ud].customParams.team_circle_param == 'static' then
			table.insert(StaticList,ud,1)
		end
	end	

	SimpleCircle = glCreateList(function()
	    glBeginEnd(GL_QUADS, function()
			glTexCoord(0.04,0.04)
			glVertex(-1,1,-1)
			glTexCoord(0.96,0.04)
			glVertex(1,1,-1)
			glTexCoord(0.96,0.96)
			glVertex(1,1,1)
			glTexCoord(0.04,0.96)
			glVertex(-1,1,1)
	    end)
	end)

	file = io.open('newfile.tmp', 'w+')
  	if (file) then
    	file:write('unitBox  0 0 0 0')
    	file:close()
    	Spring.SendCommands({'cmdcolors newfile.tmp'})
  	end
end

function widget:GameFrame(f)
	if f > 0 then
		turnMe = turnMe -0.25
		if turnMe < 0 then turnMe = 360 end
	end
end

function widget:Shutdown()
	gl.DeleteList(SimpleCircle)
	gl.DeleteList(ArrowHead)
    Spring.SendCommands({'cmdcolors cmdcolors.txt'})
end
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------


function widget:DrawWorldPreUnit()
	unitIDList = GetVisibleUnits(-1,3000,false)

	if unitIDList[1] ~= nil then
	
		glBlending(GL_SRC_ALPHA, GL_ONE)
		glDepthTest(false)
		glDepthMask(false)
	
		for _,unitID in ipairs(unitIDList) do
			if (IsUnitVisible(unitID)) then
				id = GetUnitDefID(unitID)
				teamID = GetUnitTeam(unitID)
				if (teamID) then
					--Spring.Echo(id)
					if SoldierList[id] then
						direction = GetUnitHeading(unitID)
						if direction < 0 then 
							directionTwo = direction * -1
						else 
							directionTwo = direction 
						end
						radius = 1.2*GetUnitRadius(unitID)
						glTexture(INNER)
						r,g,b = GetTeamColor(teamID)
						if IsUnitSelected(unitID) then
							glColor(1.0,1.0,0.7,1.0)
						else
							glColor(r,g,b,1.0)
						end
						glDrawListAtUnit(unitID, SimpleCircle, false, radius, 1.0, radius, directionTwo/182, 0, direction, 0)

						if ARList[id] then
							glColor(1.0,1.0,0.0,0.5)
						end
						if MGUNList[id] then
							glColor(0.0,1.0,0.0,0.5)
						end
						if RLList[id] then
							glColor(0.3,0.0,1.0,0.5)
						end
						if SMGList[id] then
							glColor(1.0,0.3,0.0,0.5)
						end
						if SNList[id] then
							glColor(0.0,0.0,1.0,0.5)
						end
						if STList[id] then
							glColor(0.0,1.0,1.0,0.5)
						end
						glTexture(OUTER)
						glDrawListAtUnit(unitID, SimpleCircle, false, radius * 1.2, 1.0, radius * 1.2, directionTwo/182, 0, direction, 0)
						glColor(0.0,1.0,0.0,0.5)
						glTexture(LOS)
						glDrawListAtUnit(unitID, SimpleCircle, false, radius, 1.0, radius, directionTwo/182, 0, direction, 0)
					end
					if StaticList[id] then					
						r,g,b = GetTeamColor(teamID)
						if IsUnitSelected(unitID) then
							radius = 1.2*GetUnitRadius(unitID)				
							glColor(1.0,1.0,0.7,0.5)
							glTexture(textureFour)
							glDrawListAtUnit(unitID, SimpleCircle, false, radius, 1.0, radius, 0, 0, 0, 0)					
						else
							radius = 1.2*GetUnitRadius(unitID)
							glTexture(textureFour)
							glColor(r,g,b,1.0)
							glDrawListAtUnit(unitID, SimpleCircle, false, radius, 1.0, radius, 0, 0, 0, 0)
						end
						
					end					
				end
			end
		end
  		glResetState()
	end	
end
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------